==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMappingOptions.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * DomainName domain;
 * RestApi api1;
 * RestApi api2;
 * domain.addBasePathMapping(api1, BasePathMappingOptions.builder().basePath("go-to-api1").build());
 * domain.addBasePathMapping(api2, BasePathMappingOptions.builder().basePath("boom").build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:08.481Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_apigateway.BasePathMappingOptions")
@software.amazon.jsii.Jsii.Proxy(BasePathMappingOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BasePathMappingOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to attach the base path mapping to a stage.
     * <p>
     * Use this property to create a base path mapping without attaching it to the Rest API default stage.
     * This property is ignored if <code>stage</code> is provided.
     * <p>
     * Default: - true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAttachToStage() {
        return null;
    }

    /**
     * The base path name that callers of the API must provide in the URL after the domain name (e.g. `example.com/base-path`). If you specify this property, it can't be an empty string.
     * <p>
     * Default: - map requests from the domain root (e.g. `example.com`). If this
     * is undefined, no additional mappings will be allowed on this domain name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBasePath() {
        return null;
    }

    /**
     * The Deployment stage of API [disable-awslint:ref-via-interface].
     * <p>
     * Default: - map to deploymentStage of restApi otherwise stage needs to pass in URL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.Stage getStage() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BasePathMappingOptions> {
        java.lang.Boolean attachToStage;
        java.lang.String basePath;
        software.amazon.awscdk.services.apigateway.Stage stage;

        /**
         * Sets the value of {@link BasePathMappingOptions#getAttachToStage}
         * @param attachToStage Whether to attach the base path mapping to a stage.
         *                      Use this property to create a base path mapping without attaching it to the Rest API default stage.
         *                      This property is ignored if <code>stage</code> is provided.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder attachToStage(java.lang.Boolean attachToStage) {
            this.attachToStage = attachToStage;
            return this;
        }

        /**
         * Sets the value of {@link BasePathMappingOptions#getBasePath}
         * @param basePath The base path name that callers of the API must provide in the URL after the domain name (e.g. `example.com/base-path`). If you specify this property, it can't be an empty string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder basePath(java.lang.String basePath) {
            this.basePath = basePath;
            return this;
        }

        /**
         * Sets the value of {@link BasePathMappingOptions#getStage}
         * @param stage The Deployment stage of API [disable-awslint:ref-via-interface].
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stage(software.amazon.awscdk.services.apigateway.Stage stage) {
            this.stage = stage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BasePathMappingOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BasePathMappingOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BasePathMappingOptions {
        private final java.lang.Boolean attachToStage;
        private final java.lang.String basePath;
        private final software.amazon.awscdk.services.apigateway.Stage stage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.attachToStage = software.amazon.jsii.Kernel.get(this, "attachToStage", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.basePath = software.amazon.jsii.Kernel.get(this, "basePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.stage = software.amazon.jsii.Kernel.get(this, "stage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.Stage.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.attachToStage = builder.attachToStage;
            this.basePath = builder.basePath;
            this.stage = builder.stage;
        }

        @Override
        public final java.lang.Boolean getAttachToStage() {
            return this.attachToStage;
        }

        @Override
        public final java.lang.String getBasePath() {
            return this.basePath;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.Stage getStage() {
            return this.stage;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAttachToStage() != null) {
                data.set("attachToStage", om.valueToTree(this.getAttachToStage()));
            }
            if (this.getBasePath() != null) {
                data.set("basePath", om.valueToTree(this.getBasePath()));
            }
            if (this.getStage() != null) {
                data.set("stage", om.valueToTree(this.getStage()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_apigateway.BasePathMappingOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BasePathMappingOptions.Jsii$Proxy that = (BasePathMappingOptions.Jsii$Proxy) o;

            if (this.attachToStage != null ? !this.attachToStage.equals(that.attachToStage) : that.attachToStage != null) return false;
            if (this.basePath != null ? !this.basePath.equals(that.basePath) : that.basePath != null) return false;
            return this.stage != null ? this.stage.equals(that.stage) : that.stage == null;
        }

        @Override
        public final int hashCode() {
            int result = this.attachToStage != null ? this.attachToStage.hashCode() : 0;
            result = 31 * result + (this.basePath != null ? this.basePath.hashCode() : 0);
            result = 31 * result + (this.stage != null ? this.stage.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/apigateway/BasePathMappingOptions.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * DomainName domain;
 * RestApi api1;
 * RestApi api2;
 * domain.addBasePathMapping(api1, BasePathMappingOptions.builder().basePath("go-to-api1").build());
 * domain.addBasePathMapping(api2, BasePathMappingOptions.builder().basePath("boom").build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:27.393Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_apigateway.BasePathMappingOptions")
@software.amazon.jsii.Jsii.Proxy(BasePathMappingOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BasePathMappingOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * Whether to attach the base path mapping to a stage.
     * <p>
     * Use this property to create a base path mapping without attaching it to the Rest API default stage.
     * This property is ignored if <code>stage</code> is provided.
     * <p>
     * Default: - true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAttachToStage() {
        return null;
    }

    /**
     * The base path name that callers of the API must provide in the URL after the domain name (e.g. <code>example.com/base-path</code>). If you specify this property, it can't be an empty string.
     * <p>
     * Default: - map requests from the domain root (e.g. `example.com`). If this
     * is undefined, no additional mappings will be allowed on this domain name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getBasePath() {
        return null;
    }

    /**
     * The Deployment stage of API [disable-awslint:ref-via-interface].
     * <p>
     * Default: - map to deploymentStage of restApi otherwise stage needs to pass in URL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.apigateway.Stage getStage() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BasePathMappingOptions> {
        java.lang.Boolean attachToStage;
        java.lang.String basePath;
        software.amazon.awscdk.services.apigateway.Stage stage;

        /**
         * Sets the value of {@link BasePathMappingOptions#getAttachToStage}
         * @param attachToStage Whether to attach the base path mapping to a stage.
         *                      Use this property to create a base path mapping without attaching it to the Rest API default stage.
         *                      This property is ignored if <code>stage</code> is provided.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder attachToStage(java.lang.Boolean attachToStage) {
            this.attachToStage = attachToStage;
            return this;
        }

        /**
         * Sets the value of {@link BasePathMappingOptions#getBasePath}
         * @param basePath The base path name that callers of the API must provide in the URL after the domain name (e.g. <code>example.com/base-path</code>). If you specify this property, it can't be an empty string.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder basePath(java.lang.String basePath) {
            this.basePath = basePath;
            return this;
        }

        /**
         * Sets the value of {@link BasePathMappingOptions#getStage}
         * @param stage The Deployment stage of API [disable-awslint:ref-via-interface].
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder stage(software.amazon.awscdk.services.apigateway.Stage stage) {
            this.stage = stage;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BasePathMappingOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BasePathMappingOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BasePathMappingOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BasePathMappingOptions {
        private final java.lang.Boolean attachToStage;
        private final java.lang.String basePath;
        private final software.amazon.awscdk.services.apigateway.Stage stage;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.attachToStage = software.amazon.jsii.Kernel.get(this, "attachToStage", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.basePath = software.amazon.jsii.Kernel.get(this, "basePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.stage = software.amazon.jsii.Kernel.get(this, "stage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.Stage.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.attachToStage = builder.attachToStage;
            this.basePath = builder.basePath;
            this.stage = builder.stage;
        }

        @Override
        public final java.lang.Boolean getAttachToStage() {
            return this.attachToStage;
        }

        @Override
        public final java.lang.String getBasePath() {
            return this.basePath;
        }

        @Override
        public final software.amazon.awscdk.services.apigateway.Stage getStage() {
            return this.stage;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAttachToStage() != null) {
                data.set("attachToStage", om.valueToTree(this.getAttachToStage()));
            }
            if (this.getBasePath() != null) {
                data.set("basePath", om.valueToTree(this.getBasePath()));
            }
            if (this.getStage() != null) {
                data.set("stage", om.valueToTree(this.getStage()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_apigateway.BasePathMappingOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BasePathMappingOptions.Jsii$Proxy that = (BasePathMappingOptions.Jsii$Proxy) o;

            if (this.attachToStage != null ? !this.attachToStage.equals(that.attachToStage) : that.attachToStage != null) return false;
            if (this.basePath != null ? !this.basePath.equals(that.basePath) : that.basePath != null) return false;
            return this.stage != null ? this.stage.equals(that.stage) : that.stage == null;
        }

        @Override
        public final int hashCode() {
            int result = this.attachToStage != null ? this.attachToStage.hashCode() : 0;
            result = 31 * result + (this.basePath != null ? this.basePath.hashCode() : 0);
            result = 31 * result + (this.stage != null ? this.stage.hashCode() : 0);
            return result;
        }
    }
}
